@@ -12,7 +12,7 @@ polling resources for externally generated content.
 For examples and full documentation see the README at
 https://github.com/litl/backoff
 """
-from backoff._decorator import on_predicate, on_exception
+from backoff._decorator import on_exception, on_predicate
 from backoff._jitter import full_jitter, random_jitter
 from backoff._wait_gen import constant, expo, fibo, runtime
 
@@ -27,4 +27,4 @@ __all__ = [
     'random_jitter',
 ]
 
-__version__ = '2.1.0'
+__version__ = "2.2.0"
